"""Proxylists Meta information."""

__title__ = 'proxylists'
__description__ = ('Package for getting useful proxy servers, '
                   'can use lists like hidemy or proxydb.')
__version__ = '0.12.2'
__author__ = 'Jesus Lara'
__author_email__ = 'jesuslarag@gmail.com'
__license__ = 'BSD'
